package com.yidian.shenghuoquan.bmerchantorder.ui

import androidx.activity.viewModels
import androidx.recyclerview.widget.GridLayoutManager
import com.yidian.bcommon.constant.XRouterPathConstants
import com.yidian.bcommon.mvvm.BaseMvvmActivity
import com.yidian.bcommon.utils.ToastUtils
import com.yidian.shenghuoquan.bmerchantorder.R
import com.yidian.shenghuoquan.bmerchantorder.adapter.MyOrderEntryAdapter
import com.yidian.shenghuoquan.bmerchantorder.adapter.OrderFilterConditionAdapter
import com.yidian.shenghuoquan.bmerchantorder.databinding.BmerchantorderActivityMerchantOrderCenterBinding
import com.yidian.shenghuoquan.bmerchantorder.dto.OrderFilterConditionDto
import com.yidian.shenghuoquan.bmerchantorder.viewmodel.MerchantOrderCenterViewModel
import com.yidian.xpage.XPageViewProtocol


/**
 * 商户订单中心
 */
class MerchantOrderCenterActivity : BaseMvvmActivity<BmerchantorderActivityMerchantOrderCenterBinding, MerchantOrderCenterViewModel>(),
  XPageViewProtocol {

  private val orderFilterAdapter by lazy { OrderFilterConditionAdapter() }

  private val myOrderEntryAdapter by lazy { MyOrderEntryAdapter() }

  override val layoutId: Int = R.layout.bmerchantorder_activity_merchant_order_center

  override val vm: MerchantOrderCenterViewModel by viewModels()

  override fun getXPageName(): String {
    return XRouterPathConstants.MERCHANT_ORDER_CENTER_ACTIVITY
  }

  override fun initView() {
    subscribeUiEvent()
    initOrderTypeEntryList()
    initFilterConditionList()
  }

  override fun onResume() {
    super.onResume()
    vm.requestOrderCenterInfo()
  }

  /**
   * 初始化筛选条件的列表
   */
  private fun initFilterConditionList() {
    binding.rvOrderEntry.layoutManager = GridLayoutManager(this, 2)
    binding.rvOrderEntry.adapter = myOrderEntryAdapter
    myOrderEntryAdapter.setOnItemClickListener { _, _, position ->
      // 更新点击orderFilterList中的item为选中状态
      vm.updateFilterList(position)
      // 使用最新的筛选条件刷新页面
      vm.requestOrderCenterInfo()
    }
    // 初始化筛选条件列表，默认选中第一个
    vm.initFilterList()
  }

  /**
   * 初始化订单入口的列表
   */
  private fun initOrderTypeEntryList() {
    binding.rvOrderEntry.layoutManager = GridLayoutManager(this, 3)
    binding.rvOrderEntry.adapter = myOrderEntryAdapter
    myOrderEntryAdapter.setOnItemClickListener { _, _, position ->
      vm.openOrderList(position)
    }
    // 初始化订单入口，默认没有小红点
    vm.initOrderEntryList()
  }

  private fun subscribeUiEvent() {
    vm.initOrderEntryListEvent.observe(this, {
      myOrderEntryAdapter.setList(it)
    })
    vm.initOrderFilterListEvent.observe(this, {
      orderFilterAdapter.setList(it)
    })

  }

}
