package com.yidian.shenghuoquan.bmerchantorder.viewmodel

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.yidian.bcommon.mvvm.BaseViewModel
import com.yidian.bcommon.utils.ToastUtils
import com.yidian.shenghuoquan.bmerchantorder.R
import com.yidian.shenghuoquan.bmerchantorder.dto.MyOrderEntryDto
import com.yidian.shenghuoquan.bmerchantorder.dto.OrderFilterConditionDto


/**
 * 订单中心
 */
class MerchantOrderCenterViewModel : BaseViewModel() {

  private lateinit var orderEntryList: MutableList<MyOrderEntryDto>
  private lateinit var orderFilterList: MutableList<OrderFilterConditionDto>

  val currentTimeLimit = MutableLiveData<String>()// 当前时间筛选条件
  val actualIncome = MutableLiveData<Double?>()// 实际收入
  val pendingSettlementIncome = MutableLiveData<Double?>()// 待结算收入

  /**
   * 订单入口 Event
   */
  private val _initOrderEntryListEvent = MutableLiveData<List<MyOrderEntryDto>>()
  val initOrderEntryListEvent: LiveData<List<MyOrderEntryDto>> = _initOrderEntryListEvent

  /**
   * 订单筛选 Event
   */
  private val _initOrderFilterListEvent = MutableLiveData<List<OrderFilterConditionDto>>()
  val initOrderFilterListEvent: LiveData<List<OrderFilterConditionDto>> = _initOrderFilterListEvent


  fun requestOrderCenterInfo() {
    // todo 筛选条件使用orderFilterList中的当前选中条件，也可以将参数声明为单独的变量，看接口要求吧

    // todo 网络请求成功后更新订单的小红点，收支账单赋值
    pendingSettlementIncome.value = 12.0
    actualIncome.value = 123.453
    updateOrderEntryList()
  }

  /**
   * 初始化订单入口，避免多次遍历重复创建对象
   */
  fun initOrderEntryList() {
    orderEntryList = mutableListOf()
    for (i in 0..4) {
      when (i) {
        0 -> {
          val dto =
            MyOrderEntryDto(orderTypeName = "全部订单", orderTypeIcon = R.drawable.b_merchant_order_icon_all_order)
          orderEntryList.add(dto)
        }
        1 -> {
          val dto =
            MyOrderEntryDto(orderTypeName = "待付款", orderTypeIcon = R.drawable.b_merchant_order_icon_waiting_payment)
          orderEntryList.add(dto)
        }
        2 -> {
          val dto =
            MyOrderEntryDto(orderTypeName = "待核销", orderTypeIcon = R.drawable.b_merchant_order_icon_waiting_write_off)
          orderEntryList.add(dto)
        }
        3 -> {
          val dto =
            MyOrderEntryDto(orderTypeName = "已完成", orderTypeIcon = R.drawable.b_merchant_order_icon_order_completed)
          orderEntryList.add(dto)
        }
        4 -> {
          val dto =
            MyOrderEntryDto(orderTypeName = "退款/已关闭", orderTypeIcon = R.drawable.b_merchant_order_icon_order_closed)
          orderEntryList.add(dto)
        }
      }
    }
    _initOrderEntryListEvent.value = orderEntryList
  }

  /**
   * 更新订单入口显示的订单数量
   */
  private fun updateOrderEntryList() {
    // todo 此list应为接口返回的订单数量
    val list = listOf("99+", "9", "90", "", "")
    list.forEachIndexed { index, s ->
      orderEntryList[index].apply {
        orderTypeNum = s
      }
    }
    _initOrderEntryListEvent.value = orderEntryList
  }

  /**
   * 初始化订单入口，避免多次遍历重复创建对象
   */
  fun initFilterList() {
    orderFilterList = mutableListOf()
    for (i in 0..2) {
      when (i) {
        0 -> {
          val dto = OrderFilterConditionDto(name = "近三个月", isSelected = true)
          orderFilterList.add(dto)
        }
        1 -> {
          val dto = OrderFilterConditionDto(name = "近一个月")
          orderFilterList.add(dto)
        }
        2 -> {
          val dto = OrderFilterConditionDto(name = "近一周")
          orderFilterList.add(dto)
        }
      }
    }
    _initOrderFilterListEvent.value = orderFilterList
  }

  fun updateFilterList(position: Int) {
    orderFilterList.forEachIndexed { index, dto ->
      when (index) {
        position -> dto.isSelected = true
        else -> dto.isSelected = false
      }
    }
    // 关闭筛选条件切换
    openTimeFilter()
  }

  fun openTimeFilter() {
    // 如果关闭则打开，反之关闭

  }

  fun openOrderList(orderType: Int) {
    // todo 修改为XPage打开页面
    when (orderType) {
      0 -> ToastUtils.showShortSafe("打开全部订单")
      1 -> ToastUtils.showShortSafe("打开待付款订单")
      2 -> ToastUtils.showShortSafe("打开待核销订单")
      3 -> ToastUtils.showShortSafe("打开已完成订单")
      4 -> ToastUtils.showShortSafe("打开退款/关闭订单")
    }

//    val map = HashMap<String, Any?>()
//    map[IntentConstants.KEY_EXTRA_MERCHANT_ORDER_LIST] = orderType
//    XPageManager.push(XRouterPathConstants.MERCHANT_ORDER_LIST_ACTIVITY, map)

  }

}
